#define MROP M0
#include "mfbmap.h"
#include "../../../mfb/mfbblt.c"
